@@ -9,7 +9,7 @@ use URI;
 use Try::Tiny;
 use Carp;
 
-our $VERSION = "0.04";
+our $VERSION = "0.05";
 our $API_BASE = 'api.mailgun.net/v3';
 
 use Class::Accessor::Lite (
@@ -172,6 +172,13 @@ sub delete_list_member {
     $self->decode_response($res);
 }
 
+sub event {
+    my ($self, $args) = @_;
+
+    my $res = $self->client->get($self->api_url("events"));
+    $self->decode_response($res);
+}
+
 1;
 __END__
 
